@@ -7,7 +7,7 @@
     client side, are automatically installed.
 
     Copyright 2019-2021 DeNova
-    Last modified: 2020-01-02
+    Last modified: 2020-06-20
 
     Written because none of the standard python locking mechanisms work reliably.
 
@@ -26,18 +26,18 @@ from traceback import format_exc
 from denova.os import lock
 from denova.os.process import is_pid_active, is_program_running
 from denova.os.user import require_user
-from denova.python.log import get_log
+from denova.python.log import Log
 from denova.python.times import timestamp
 
 
-CURRENT_VERSION = '1.2.7'
+CURRENT_VERSION = '1.2.8'
 COPYRIGHT = 'Copyright 2019-2021 DeNova'
 LICENSE = 'GPLv3'
 
 # globals so they aren't initialized on every connection
 locks = {}
 count = 0
-log = get_log()
+log = Log()
 
 
 class LockServer(socketserver.BaseRequestHandler):
